@@ -31,7 +31,7 @@ You should not talk to this object direct but by using the controller.
 
 import utils
 #set_locale()
-import world,worldMap,stepper,guiWorld
+import world,worldMap,stepper,guiWorld, gvrparser
 import sys,os,time
 import logging
 
@@ -112,7 +112,8 @@ class GvrModel:
             # calls: setLine
             # See stepper.Stepper.step
             self.myStepper = stepper.Stepper(codestring, myGuiWorld,self.controller)
-        except Exception,info:
+        except gvrparser.BadCommand,info:
+            utils.trace_error()
             self.controller.give_error(str(info))
         else:
             if step:
@@ -182,14 +183,21 @@ class GvrModel:
         self.controller.give_info(message)
         return 1
     def updateWorldBitmapAfterMove(self,oldcoords=None):
-        """Wrapper needed because stepper calls it after a move of guido.
-        oldcoords are the old robot coords"""
+        """Wrapper needed because stepper calls it after a move from guido.
+        oldcoords are the old robot coords.
+        Called from guiWorld.GuiWorld"""
         if not self.logicworld:
             print "no logicworld in GvrModel updateWorldBitmapAfterMove"
             print "This should not happening"
         self.controller.world_robot_state_changed(self.logicworld,oldcoords)
         self.controller.world_beepers_state_changed(self.logicworld)
-        
+    
+    def updateWorldBitmapAfterBeeper(self):
+        """Wrapper needed because stepper calls it after a beeper action from guido.
+        oldcoords are the old robot coords.
+        Called from guiWorld.GuiWorld"""
+        self.controller.world_beepers_state_changed(self.logicworld)
+       
     def on_world_reload(self,worldcode):
         """ This will return a world object representing the logic from the
         world code, it also makes it a class attribute.
