@@ -26,6 +26,7 @@ import utils
 import pygtk
 pygtk.require('2.0')
 import gtk
+import re
 
 # try to get the proper gtksourceview bindings
 if utils.platform == 'XO':
@@ -108,16 +109,19 @@ class Editor:
                     self.srcbuffer.set_language(man.get_language(id))
                     break
             self.srcview.set_tab_width(4)
-            
         # some methods that are the same on version 1 and 2    
         self.tag_h = self.srcbuffer.create_tag(background='lightblue')
         self.srcbuffer.set_max_undo_levels(10)
         self.srcview.set_show_line_numbers(True)
         self.srcview.set_insert_spaces_instead_of_tabs(True)
+        self.srcview.set_auto_indent(True)
         #self.srcview.set_wrap_mode(gtk.WRAP_CHAR)        
         self.parent.add(self.srcview)
         self.parent.show_all()
-        
+
+        self.srcbuffer.connect("delete-range",self.delete_tabs)
+        # self.format results in a "Invalid text buffer iterator" warning
+        self.srcbuffer.connect("insert-text", self.format)
         self.old_start_iter = None
 
     def get_all_text(self):
@@ -143,6 +147,7 @@ class Editor:
             print "Failed to set text in source buffer"
             print info
             return
+        
         self.srcbuffer.set_text(utxt)
         
     def set_highlight(self,line):
@@ -158,6 +163,22 @@ class Editor:
     def reset_highlight(self):
         self.set_highlight(0)
         
-    
-            
-
+    def format(self,srcview,iter,text,leng):
+        startiter = self.srcbuffer.get_start_iter()
+        enditer = self.srcbuffer.get_iter_at_mark(self.srcbuffer.get_insert())
+        code = self.srcbuffer.get_text(startiter,enditer)
+        if len(code) > 0 and code[-1] == ":" and text == "\n":
+            line = code.split('\n')[-1]
+            indent = re.match("^\s*", line).group()
+            self.srcbuffer.insert_interactive_at_cursor("\n"+indent + "    ", True)
+        
+    def delete_tabs(self,srcview,start,end):
+        startiter = self.srcbuffer.get_start_iter()
+        code = self.srcbuffer.get_text(startiter,end)
+        cursor = self.srcbuffer.get_iter_at_mark(self.srcbuffer.get_insert())
+        line = code.split('\n')[-1]
+        spaces = re.match("^\s*", line).group()
+        if self.srcbuffer.get_text(start,end) == " " and len(line) == len(spaces):
+            if len(spaces) >= 4:
+                cursor.backward_chars(4)
+                self.srcbuffer.delete(cursor, end)
