@@ -56,6 +56,7 @@ class WarningDialog(gtk.MessageDialog):
                             message_format=message_format)
         self.connect("response", self.response)
         self.set_markup('%s%s%s' % ('<b>',txt,'</b>'))
+        self.set_title(_('Warning'))
         self.show()
     def response(self,*args):
         """destroys itself on a respons, we don't care about the response value"""
@@ -69,6 +70,7 @@ class ErrorDialog(WarningDialog):
                             buttons=gtk.BUTTONS_CLOSE,
                             message_format='',
                             txt=txt)
+        self.set_title(_('Error'))
 class InfoDialog(WarningDialog):
     def __init__(self,txt):
         WarningDialog.__init__(self,parent=None,
@@ -77,6 +79,7 @@ class InfoDialog(WarningDialog):
                             buttons=gtk.BUTTONS_CLOSE,
                             message_format='',
                             txt=txt)
+        self.set_title(_('Information'))
 class YesNoDialog(gtk.MessageDialog):
     def __init__(self,parent=None,flags=gtk.DIALOG_MODAL,type=gtk.MESSAGE_INFO,
                     buttons=gtk.BUTTONS_YES_NO,message_format='',txt=''):
@@ -87,6 +90,7 @@ class YesNoDialog(gtk.MessageDialog):
                             message_format=message_format)
         #self.connect("response", self.response)
         self.set_markup('%s%s%s' % ('<b>',txt,'</b>'))
+        self.set_title(_('Question ?'))
         self.show()
 
 class BeeperDialog(YesNoDialog):
@@ -101,9 +105,11 @@ class BeeperDialog(YesNoDialog):
         hbox = gtk.HBox(homogeneous=False, spacing=4)
         label = gtk.Label(_("Number of beepers:"))
         self.entrybox = gtk.Entry(3)
+        self.entrybox.set_flags(gtk.CAN_FOCUS)
         hbox.pack_start(label,False,False,0)
         hbox.pack_start(self.entrybox,False,False,0)
         self.vbox.pack_start(hbox, True, True, 0)
+        self.entrybox.grab_focus()
         self.vbox.show_all()
     def get_choice(self):
         choice = self.entrybox.get_text()
@@ -112,6 +118,8 @@ class BeeperDialog(YesNoDialog):
         except ValueError,info:
             print info
             beepers = 0
+        if beepers < 0:
+            beepers = 0
         return beepers
 
 # As a reminder:
@@ -518,6 +526,12 @@ class WBCanvas(Canvas):
             print "grid x,rx,y,ry",x,rx,y,ry
         return (x,rx,y,ry)
 
+    def reload_button_activated(self, wcode):
+        n_wcode = []
+        for line in wcode:
+            n_wcode.append(line+'\n')
+        self.wcode = n_wcode
+
     def on_button_press_event_cb(self,widget, event):
         # add the wall to the editor and worldobject then call draw_wall
         # which uses the world object.
@@ -586,10 +600,10 @@ class WBCanvas(Canvas):
             x,xx,y,yy = self._calculate_position(event.x,event.y)
             if x < 1 or y < 1:
                 return True
-            # placeholder: check code for beepers on this position
+            # TODO: check code for beepers on this position
             # and fill the dialog if true
             #print self.wcode
-            dlg = BeeperDialog(txt=_("Please give the number of beepers\nto place on %d,%d") % (x,y))
+            dlg = BeeperDialog(txt=_("Please give the number of beepers\nto place on %d,%d\n (Number must be > 0)") % (x,y))
             beepersline = '%s %s %s' % (_('beepers'),x,y)
             for line in self.wcode:
                 if line.find(beepersline) != -1:
@@ -600,36 +614,33 @@ class WBCanvas(Canvas):
             if response == gtk.RESPONSE_OK:
                 num_beepers = dlg.get_choice()
                 if not num_beepers:
+                    self.gvrparent.world_editor.editor.set_text(self.wcode)
+                    self.gvrparent.on_button_reload()
                     dlg.destroy()
+                    WarningDialog(txt=_('Beeper values must be zero or more.\nUse zero as the value to remove beeper(s)'))
                     return True
                 bline = "%s %d %d %d\n" % (_('beepers'),x,y,num_beepers)
             dlg.destroy()
         # code used by button 1 and 3    
         wcode = filter(None,[wline,bline])
         if wcode:
-##            self.stuff_to_draw = [self._draw_empty_world,
-##                                self._draw_robot,
-##                                self._draw_beepers,
-##                                self._draw_labels,
-##                                self._draw_walls]
-            #print wcode
-            if wcode[0] in self.wcode:
-                #print "double:", wcode[0]
-                self.wcode.remove(wcode[0])
-            else:                
-                self.wcode = self.wcode + wcode
-            self.gvrparent.world_editor.editor.set_text(self.wcode)
             if event.button == 1:
                 # t isn't used
                 t,x,y,d = wline.split(' ')
                 result = self.world.setWall_wb(x,y,lookup_dir_dict[d[:-1]])
-                #print 'result',result
                 if result[2] == 0:
                     # remove wall
                     self._remove_wall(result[0],result[1][0],result[1][1])
+                    self.wcode.remove(wcode[0])
                 else:
                     self._draw_walls(self)
-            else:
+                    if wcode[0] not in self.wcode:
+                        self.wcode = self.wcode + wcode
+            if event.button == 3:
+                if wcode[0] not in self.wcode:
+                        self.wcode = self.wcode + wcode
+            self.gvrparent.world_editor.editor.set_text(self.wcode)
+            if event.button == 3:
                 self.gvrparent.on_button_reload()
         return True
         
