@@ -75,7 +75,7 @@ class Window(SimpleGladeApp):
         if PLATFORM != 'XO':
             #self.parentGUI = gtk.Window(gtk.WINDOW_TOPLEVEL)
             self.parentGUI = self.window_main
-            self.windowtitle = "Gvrng"
+            self.windowtitle = "GvRng"
             self.parentGUI.set_title(self.windowtitle)
             file = os.path.join(os.getcwd(),'gui-gtk','pixmaps','gvrIcon.bmp')
             try:
@@ -390,6 +390,9 @@ class Window(SimpleGladeApp):
             self.controller.on_button_reload(wcode)
         self.program_editor.reset_highlight()
         self._canvas._reset_offset()
+        # notify wbuilder that possibly the world editor code is changed.
+        if self.WB_ACTIVATED and wcode:
+            self._canvas.reload_button_activated(wcode)
         return True
 
     def on_button_step(self, widget, *args):
@@ -612,6 +615,9 @@ class TextEditorWin(SimpleGladeApp):
             Widgets.WarningDialog(txt=_("No content to save"))
             return
         if self.loaded_file_path:
+            ext = '.'+str(self)
+            if not self.loaded_file_path.endswith(ext):
+                self.loaded_file_path = self.loaded_file_path+ext
             status = utils.save_file(self.loaded_file_path,txt)
             if status:
                Widgets.ErrorDialog(txt=status)
@@ -640,7 +646,7 @@ class TextEditorWin(SimpleGladeApp):
         #print 'edittxt',edittxt
         #print 'loaded_txt',self.loaded_txt
         if edittxt != self.loaded_txt:
-            dlg = Widgets.YesNoDialog(txt=_("The editor's content is changed.\nDo you want to save it?"))
+            dlg = Widgets.YesNoDialog(txt=_("The %s editor's content is changed.\nDo you want to save it?" % self.name()))
             response = dlg.run()
             dlg.destroy()
             if response == gtk.RESPONSE_YES:
@@ -696,17 +702,11 @@ class CodeTextEditorWin(TextEditorWin):
         self.parent.alignment19.add(self.vbox4)
     def __str__(self):
         return 'gvr'
-    
+    def name(self):
+        return 'Code'
     def on_new1_activate(self, widget=None, file=''):
+        self.on_quit2_activate()
         self.parent.new_program_editor()
-##        if file:
-##            txt = utils.load_file(file)
-##            if txt:
-##                self.set_text(file,txt)
-##        #self.program_editor.EditorWin.show()
-##        for b in ('execute','step','abort'):
-##            self.parent._set_sensitive_button(b,True)
-##        self.register_observer(self.parent._programeditor_observer_callback)
     
     def on_open1_activate(self, widget=None,file=''):
         if not file:
@@ -741,19 +741,12 @@ class WorldTextEditorWin(TextEditorWin):
         self.parent.alignment18.add(self.vbox4)
     def __str__(self):
         return 'wld'
-    
+    def name(self):
+        return 'World'
     def on_new1_activate(self,widget=None,file=''):
+        self.on_quit2_activate()
         self.parent.new_world_editor()
-##        self.on_quit2_activate()# this takes care of saving content yes/no
-##        #self.new()
-##        if file:
-##            txt = utils.load_file(file)
-##            if txt:
-##                self.set_text(file,txt)
-##                self.parent.on_button_reload()
-##        self.parent._set_sensitive_button('reload',True)
-##        self.register_observer(self.parent._worldeditor_observer_callback)
-    
+   
     def on_open1_activate(self,widget=None,file=''):
         self.on_quit2_activate()# this takes care of saving content yes/no
         if not file:
