@@ -185,7 +185,7 @@ def parseBlock(remainingTokens):
         pass
     for statement in statements:
         if statement.indent != defaultIndent:
-            raise IndentError, statement.line
+            raise IndentError, statement
     return Block(statements)
 
 def eatLine(tokens, startIndex):
@@ -208,7 +208,7 @@ def eatBlock(tokens, startIndex):
         # You can safely assume that there will always
         # be at least one token on the current line,
         # or this would have never been called.
-        raise ExpectedBlock(currentLine[0]['line']+1)
+        raise ExpectedBlock , currentLine[0]['line']+1
     block = tokens[startIndex:end]
     restOfCode = tokens[end:]
     return currentLine, block, restOfCode
@@ -256,6 +256,13 @@ def parseDoLoop(tokens):
     iterator = currentLine[1]['statement']
     isIterator(currentLine[1])
     blockObj = parseBlock(block)
+    try:
+        int(iterator)
+    except ValueError, info:
+        print info
+        raise BadCommand, (currentLine[1], _('Argument for "%s" must be an integer, not %s' % (_('do'), iterator)))
+    if int(iterator) < 1:
+        raise BadCommand, (currentLine[1], _('Argument for "%s" must be greater than zero' % _('do')))
     return DoLoop(currentLine[0]['indent'], iterator, blockObj), remainingTokens
 
 def parseDefine(tokens):
@@ -355,48 +362,91 @@ class ParseEmptyFileException(ParseError):
     def __str__(self): return _('Your program must have commands.')
 
 class BadCommand(ParseError):
+    def __init__(self, token, msg=''):
+        self.command = token['statement']
+        self.line = token['line']
+        self.msg = msg
+    def __str__(self):
+        return _("Line %i:\n%s") % (self.line+1, self.msg)
+
+class BadIterator(BadCommand):
     def __init__(self, token):
         self.command = token['statement']
         self.line = token['line']
     def __str__(self):
         return _("Line %i:\n%s") % (self.line+1, self.error())
-
-class BadIterator(BadCommand):
     def error(self):
         return _("Expected positive integer\nGot: %s") % self.command
 
 class IndentError(BadCommand):
-    def __init__(self, line):
-        self.line = line
+    def __init__(self, token):
+        self.command = token['statement']
+        self.line = token['line']
+    def __str__(self):
+        return _("Line %i:\n%s") % (self.line+1, self.error())
     def error(self):
         return _("Indentation error")
 
 class ExpectedBlock(BadCommand):
     def __init__(self, line):
         self.line = line
+    def __str__(self):
+        return _("Line %i:\n%s") % (self.line+1, self.error())
     def error(self):
         return _("Expected code to be indented here")
 
 class LineTooShort(BadCommand):
+    def __init__(self, token):
+        self.command = token['statement']
+        self.line = token['line']
+        
+    def __str__(self):
+        return _("Line %i:\n%s") % (self.line+1, self.error())
     def error(self):
         return _("'%s' statement is incomplete") % self.command
 
 class NoColon(BadCommand):
+    def __init__(self, token):
+        self.command = token['statement']
+        self.line = token['line']
+    def __str__(self):
+        return _("Line %i:\n%s") % (self.line+1, self.error())
     def error(self):
         return _("Expected '%s' statement to end in ':'") % self.command
 
 class BadStatement(BadCommand):
+    def __init__(self, token):
+        self.command = token['statement']
+        self.line = token['line']
+    def __str__(self):
+        return _("Line %i:\n%s") % (self.line+1, self.error())
     def error(self):
         return _('"%s" not defined') % (self.command)
 
 class BadTest(BadCommand):
+    def __init__(self, token):
+        self.command = token['statement']
+        self.line = token['line']
+    def __str__(self):
+        return _("Line %i:\n%s") % (self.line+1, self.error())
     def error(self):
         return _('"%s" is not a valid test') % (self.command)
 
 class BadName(BadCommand):
+    def __init__(self, token):
+        self.command = token['statement']
+        self.line = token['line']
+    def __str__(self):
+        return _("Line %i:\n%s") % (self.line+1, self.error())
     def error(self):
         return _('"%s" is not a valid name') % (self.command)
 
 class DoubleDefinition(BadCommand):
+    def __init__(self, token):
+        self.command = token['statement']
+        self.line = token['line']
+        
+    def __str__(self):
+        return _("Line %i:\n%s") % (self.line+1, self.error())
     def error(self):
         return _('"%s" has already been defined') % (self.command)
