@@ -14,6 +14,8 @@ class StdoutCatcher:
         self.outfile = open(self.pyoutf, 'a')
         self.outfile.write(msg)
         self.outfile.close()
+    def flush(self):
+        return None        
 
 class StderrCatcher:
     def __init__(self):
@@ -24,6 +26,8 @@ class StderrCatcher:
         self.outfile = open(self.pyerrf, 'a')
         self.outfile.write(msg)
         self.outfile.close()
+    def flush(self):
+        return None        
 
 sys.stdout = StdoutCatcher()
 sys.stderr = StderrCatcher()
