@@ -2,8 +2,8 @@
 # By putting it in a seperate file we don't have to import
 # gvr to get a version number
 
-VERSION = "4.1"
-#last changed on 01-06 --sz--
+VERSION = "4.4"
+#last changed on 21-01-2010 --sz--
 
 # The %s formatters are set by gvr.py
 ABOUT_TEXT = """
@@ -12,7 +12,7 @@ A implementation of the Guido van Robot
 programming language based on Karel the Robot\n
 This version is specially designed for the OLPC XO laptop.\n
 Core Programmers:
-    Stas Z - stas.zytkiewicz@gmail.com
+    Stas Zytkiewicz - stas.zytkiewicz@gmail.com
     Waseem Daher - wdaher@mit.edu
     Steve Howell - showell@zipcon.net\n
     Paul Carduner - paulcarduner@ibiblio.org
