@@ -1,3 +1,4 @@
+# Copyright 2010 S. Zytkiewicz stas.zytkiewicz@gmail.com
 #  Copyright (C) 2001 Steve Howell
 #  You must read the file called INFO.txt before distributing this code.
 # ---
@@ -6,7 +7,7 @@
 
 from world import NORTH,SOUTH,EAST,WEST
 from utils import trace_error
-
+import types
 import re,gettext
 
 # Use this to be able to extract strings for translation by pygettext.py
@@ -74,7 +75,6 @@ def readWorld(lines, world):
     useGuido = False
     linenumber = 0
     worldSize = None
-    #print "worldMap lines",lines
     for line in lines:
         linenumber += 1
         try:
@@ -85,15 +85,32 @@ def readWorld(lines, world):
                 keyword = tokens[0]
                 if lookup_dict.has_key(keyword):
                     keyword = lookup_dict[keyword]
-                dir = tokens[3]
-                if lookup_dir_dict.has_key(dir):
-                    dir = lookup_dir_dict[dir]
-                    tokens[3] = dir
+                if keyword == _('ROBOT') or keyword == 'ROBOT':
+                    if len(tokens) < 4:
+                        raise WorldMapException(linenumber,_('Robot direction argument missing'))
+                    dir = tokens[3]
+                    if lookup_dir_dict.has_key(dir):
+                        dir = lookup_dir_dict[dir]
+                        tokens[3] = dir
+                    else:
+                        print lookup_dir_dict.has_key(dir), lookup_dir_dict, dir
+                        raise WorldMapException(linenumber, _('No valid direction given for the robot'))
                 if keyword ==_('WALL') or keyword == 'WALL':
                     tokens[0] = keyword
                     #print "wall",tokens
                     checkDirection(linenumber, dir)
                     #print "tokens",tokens
+                    if len(tokens) < 3:
+                        raise WorldMapException(linenumber,_('Too little %s arguments' % _('WALL')))
+                    else:
+                        if len(tokens) == 5:
+                            try:
+                                int(tokens[4])
+                            except ValueError:
+                                raise WorldMapException(linenumber, _('%s length argument must be an integer' % _('WALL')))
+                            else:
+                                if int(tokens[4]) < 1:
+                                    raise WorldMapException(linenumber,_('%s length argument must be greater than zero' % _('WALL')))
                     world.setWall(*tokens[1:])
                 elif keyword == _('ROBOT') or keyword == 'ROBOT':
                     if definedRobot:
@@ -131,8 +148,9 @@ def readWorld(lines, world):
                     worldSize = (avenues, streets)
                 else:
                     raise WorldMapException(linenumber,_("Cannot understand: %s") % line)
-        except Exception,info:
-            info = _("Error in line %s:\n%s\nCheck your world file for syntax errors") % (linenumber,line)
+        except (WorldMapException, Exception),e:
+            #trace_error()
+            info = _("Error: %s\n in line %s: %s\nCheck your world file for syntax errors") % (e, linenumber,line)
             raise WorldMapException(linenumber, info)
     if not definedRobot:
         raise WorldMapException(linenumber, _("The world map seems to be missing information."))
